@@ -36,7 +36,7 @@ from apis_core.apis_entities.models import AbstractEntity
 from .models import DataSource, ImportProject
 
 log = logging.getLogger("mylogger")
-log.setLevel(logging.WARNING)
+log.setLevel(logging.INFO)
 
 
 
@@ -122,7 +122,6 @@ def get_custom_generic_entities_form(entity):
 
     class CustomGenericEntitiesForm(forms.ModelForm):
         class Meta:
-            print("entity in forms is: ", entity)
             model = AbstractEntity.get_entity_class_of_name(entity)
 
             exclude = [
